@@ -1,10 +1,10 @@
 from autonomous import log
-from autonomous.model.automodel import AutoModel
+from autonomous.model import AutoModel, AutoAttribute
 
 
 class Model(AutoModel):
     # set model default attributes
     attributes = {
-        "name": "",
+        "name": AutoAttribute("TEXT", default=""),
         "age": None,
     }
