@@ -3,27 +3,14 @@
 # external Modules
 from flask import Blueprint, render_template, request, session
 from autonomous import log
+from autonomous.auth import auth_required
 
 admin_page = Blueprint("admin", __name__)
 
 
 @admin_page.route("/", methods=("GET",))
+@auth_required
 def index():
     if request.form:
         session.update(request.form)
-    return render_template("index.html")
-
-
-@admin_page.route("/add", methods=("POST",))
-def add():
-    return {"result": "success"}
-
-
-@admin_page.route("/update", methods=("POST",))
-def updates():
-    return "updated"
-
-
-@admin_page.route("/delete", methods=("POST",))
-def delete():
-    return "deleted"
+    return render_template("admin.html")
