@@ -3,7 +3,9 @@
 """
 from datetime import datetime
 
-from autonomous import AutoModel, log
+from autonomous import log
+from autonomous.model.autoattribute import AutoAttribute
+from autonomous.model.automodel import AutoModel
 
 
 class AutoUser(AutoModel):
@@ -12,12 +14,12 @@ class AutoUser(AutoModel):
     """
 
     attributes = {
-        "name": "",
-        "email": "",
+        "name": AutoAttribute("TEXT", required=True),
+        "email": AutoAttribute("TAG", required=True),
         "last_login": datetime.now(),
         "state": "unauthenticated",
-        "token": "",
         "provider": None,
+        "token": None,
     }
 
     @classmethod
@@ -26,18 +28,20 @@ class AutoUser(AutoModel):
         Initiates the authentication process.
         Returns a redirect URL which should be used to redirect the user to the OpenID provider for authentication.
         """
-        log(user_info)
-        user = AutoUser.find(email=user_info.get("email"))
+        # log(user_info)
+        user = cls.find(email=user_info["email"])
+        # log(user, user_info)
         if not user:
-            user = AutoUser()
+            # log("Creating new user...")
+            user = cls(**user_info)
 
         # parse user_info into a user object
         user.name = user_info["name"]
         user.email = user_info["email"]
-        user.token = token
         user.last_login = datetime.now()
         user.state = "authenticated"
         user.save()
+        # log(user.pk)
         return user
 
     @property
@@ -46,3 +50,10 @@ class AutoUser(AutoModel):
         Returns True if the user is authenticated, False otherwise.
         """
         return self.state == "authenticated"
+
+    @property
+    def is_guest(self):
+        """
+        Returns True if the user is a guest, False otherwise.
+        """
+        return self.state == "guest"
