@@ -2,8 +2,6 @@ import inspect
 import logging
 import os
 
-from icecream import ic
-
 # class LogFilter(logging.Filter):
 #     def filter(self, record):
 #         return record.levelno == LOG_LEVEL
@@ -28,8 +26,6 @@ class Logger:
         self.logger = logging.getLogger("gunicorn.error")
         level = os.environ.get("LOG_LEVEL") or self.logger.level
         self.logger.setLevel(log_levels.get(level, "DEBUG"))
-        prefix = f"{os.environ.get('APP_NAME ', 'APP')}| "
-        ic.configureOutput(prefix=prefix)
         self.enabled = True
 
     def set_level(self, level):
@@ -43,11 +39,12 @@ class Logger:
             caller = inspect.stack()[1]
             fn = caller.filename.split("/")[-1]
             msg = f"\n\n{'='*20}\t{fn}:{caller.function}()::{caller.lineno}\t{'='*20}\n"
-            msg += "\n========\n"
+            msg += f"\n{'='*20}\n"
             if args:
-                msg += ic.format(args)
+                msg += "\n---\n".join([f"{v}" for v in args])
             if kwargs:
-                msg += ic.format(kwargs)
+                msg += "\n---\n".join([f"{k} : {v}" for k, v in kwargs.items()])
+            msg += f"\n{'='*20}\n"
             self.logger.log(self.logger.level, f"{msg}\n")
 
 
